@@ -47,13 +47,9 @@
 #include <QSurface>
 #include <QWindow>
 #include <QOpenGLTexture>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #ifdef QT_OPENGL_LIB
 #include <QtOpenGL/QOpenGLDebugLogger>
 #endif
-#else
-#include <QOpenGLDebugLogger>
-#endif
 
 QT_BEGIN_NAMESPACE
 
@@ -65,8 +61,6 @@ QT_BEGIN_NAMESPACE
 #define GL_DRAW_FRAMEBUFFER 0x8CA9
 #endif
 
-using namespace Qt3DCore;
-
 namespace Qt3DRender {
 namespace Render {
 namespace OpenGL {
@@ -87,14 +81,14 @@ unsigned int nextFreeContextId()
 
 namespace {
 
-GLBuffer::Type attributeTypeToGLBufferType(QAttribute::AttributeType type)
+GLBuffer::Type attributeTypeToGLBufferType(Qt3DCore::QAttribute::AttributeType type)
 {
     switch (type) {
-    case QAttribute::VertexAttribute:
+    case Qt3DCore::QAttribute::VertexAttribute:
         return GLBuffer::ArrayBuffer;
-    case QAttribute::IndexAttribute:
+    case Qt3DCore::QAttribute::IndexAttribute:
         return GLBuffer::IndexBuffer;
-    case QAttribute::DrawIndirectAttribute:
+    case Qt3DCore::QAttribute::DrawIndirectAttribute:
         return GLBuffer::DrawIndirectBuffer;
     default:
         Q_UNREACHABLE();
@@ -340,8 +334,7 @@ GLint glAttachmentPoint(const QRenderTargetOutput::AttachmentPoint &attachmentPo
     case QRenderTargetOutput::Stencil:
         return GL_STENCIL_ATTACHMENT;
     default:
-        Q_UNREACHABLE();
-        return GL_NONE;
+        Q_UNREACHABLE_RETURN(GL_NONE);
     }
 }
 
@@ -471,6 +464,8 @@ void SubmissionContext::endDrawing(bool swapBuffers)
 void SubmissionContext::activateRenderTarget(Qt3DCore::QNodeId renderTargetNodeId, const AttachmentPack &attachments, GLuint defaultFboId)
 {
     GLuint fboId = defaultFboId; // Default FBO
+    resolveRenderTargetFormat(); // Reset m_renderTargetFormat based on the default FBO
+
     if (renderTargetNodeId) {
         // New RenderTarget
         if (!m_renderTargets.contains(renderTargetNodeId)) {
@@ -481,9 +476,10 @@ void SubmissionContext::activateRenderTarget(Qt3DCore::QNodeId renderTargetNodeI
                 fboId = createRenderTarget(renderTargetNodeId, attachments);
             }
         } else {
-            fboId = updateRenderTarget(renderTargetNodeId, attachments, true);
+            fboId = updateRenderTarget(renderTargetNodeId, attachments, true); // Overwrites m_renderTargetFormat based on custom FBO
         }
     }
+
     m_activeFBO = fboId;
     m_activeFBONodeId = renderTargetNodeId;
     m_glHelper->bindFrameBufferObject(m_activeFBO, GraphicsHelperInterface::FBODraw);
@@ -613,6 +609,7 @@ QImage SubmissionContext::readFramebuffer(const QRect &rect)
     QImage::Format imageFormat;
     uint stride;
 
+    // m_renderTargetFormat is set when the current RV FBO is set in activateRenderTarget
     /* format value should match GL internalFormat */
     GLenum internalFormat = m_renderTargetFormat;
 
@@ -1498,7 +1495,7 @@ void SubmissionContext::uploadDataToGLBuffer(Buffer *buffer, GLBuffer *b, bool r
         // We have a partial update
         if (update->offset >= 0) {
             //accumulate sequential updates as single one
-            int bufferSize = update->data.size();
+            qsizetype bufferSize = update->data.size();
             auto it2 = it + 1;
             while ((it2 != updates.end())
                    && (it2->offset - update->offset == bufferSize)) {
@@ -1518,7 +1515,7 @@ void SubmissionContext::uploadDataToGLBuffer(Buffer *buffer, GLBuffer *b, bool r
             // We have an update that was done by calling QBuffer::setData
             // which is used to resize or entirely clear the buffer
             // Note: we use the buffer data directly in that case
-            const int bufferSize = buffer->data().size();
+            const qsizetype bufferSize = buffer->data().size();
             b->allocate(this, bufferSize, false); // orphan the buffer
             b->allocate(this, buffer->data().constData(), bufferSize, false);
         }
